/********************************************************************************
** Form generated from reading UI file 'sshtunnelwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SSHTUNNELWIDGET_H
#define UI_SSHTUNNELWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SshTunnelWidget
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *use_ssh_tunnel;
    QGroupBox *ssh_groupBox;
    QFormLayout *formLayout_4;
    QCheckBox *use_loopback;
    QLabel *label;
    QSpinBox *ssh_tunnel_port;
    QLabel *label_2;
    QLineEdit *ssh_tunnel_user_name;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *SshTunnelWidget)
    {
        if (SshTunnelWidget->objectName().isEmpty())
            SshTunnelWidget->setObjectName("SshTunnelWidget");
        SshTunnelWidget->resize(309, 180);
        verticalLayout = new QVBoxLayout(SshTunnelWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        use_ssh_tunnel = new QCheckBox(SshTunnelWidget);
        use_ssh_tunnel->setObjectName("use_ssh_tunnel");

        verticalLayout->addWidget(use_ssh_tunnel);

        ssh_groupBox = new QGroupBox(SshTunnelWidget);
        ssh_groupBox->setObjectName("ssh_groupBox");
        formLayout_4 = new QFormLayout(ssh_groupBox);
        formLayout_4->setObjectName("formLayout_4");
        use_loopback = new QCheckBox(ssh_groupBox);
        use_loopback->setObjectName("use_loopback");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, use_loopback);

        label = new QLabel(ssh_groupBox);
        label->setObjectName("label");

        formLayout_4->setWidget(1, QFormLayout::ItemRole::LabelRole, label);

        ssh_tunnel_port = new QSpinBox(ssh_groupBox);
        ssh_tunnel_port->setObjectName("ssh_tunnel_port");
        ssh_tunnel_port->setMinimum(1);
        ssh_tunnel_port->setMaximum(65535);
        ssh_tunnel_port->setValue(22);

        formLayout_4->setWidget(1, QFormLayout::ItemRole::FieldRole, ssh_tunnel_port);

        label_2 = new QLabel(ssh_groupBox);
        label_2->setObjectName("label_2");

        formLayout_4->setWidget(3, QFormLayout::ItemRole::LabelRole, label_2);

        ssh_tunnel_user_name = new QLineEdit(ssh_groupBox);
        ssh_tunnel_user_name->setObjectName("ssh_tunnel_user_name");

        formLayout_4->setWidget(3, QFormLayout::ItemRole::FieldRole, ssh_tunnel_user_name);


        verticalLayout->addWidget(ssh_groupBox);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label->setBuddy(ssh_tunnel_port);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SshTunnelWidget);

        QMetaObject::connectSlotsByName(SshTunnelWidget);
    } // setupUi

    void retranslateUi(QWidget *SshTunnelWidget)
    {
        SshTunnelWidget->setWindowTitle(tr2i18n("SSH tunnel", nullptr));
        use_ssh_tunnel->setText(tr2i18n("Connect via SSH tunnel", nullptr));
        ssh_groupBox->setTitle(tr2i18n("SSH tunnel options", nullptr));
        use_loopback->setText(tr2i18n("Tunnel via loopback address", nullptr));
        label->setText(tr2i18n("Port:", nullptr));
        label_2->setText(tr2i18n("User name:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SshTunnelWidget: public Ui_SshTunnelWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SSHTUNNELWIDGET_H

