/********************************************************************************
** Form generated from reading UI file 'rdppreferences.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RDPPREFERENCES_H
#define UI_RDPPREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"
#include "kpasswordlineedit.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_RdpPreferences
{
public:
    QGridLayout *gridLayout;
    QTabWidget *settingsTabs;
    QWidget *mainSettingsTab;
    QGridLayout *gridLayoutMain;
    QLabel *resolutionLabel;
    KComboBox *kcfg_Resolution;
    QHBoxLayout *hboxLayout;
    QLabel *widthLabel;
    QSpinBox *kcfg_Width;
    QLabel *heightLabel;
    QSpinBox *kcfg_Height;
    QCheckBox *kcfg_ScaleToSize;
    QLabel *accelerationLabel;
    KComboBox *kcfg_Acceleration;
    QLabel *colorDepthLabel;
    KComboBox *kcfg_ColorDepth;
    QLabel *desktopScaleFactorLabel;
    QHBoxLayout *hboxLayout1;
    KComboBox *kcfg_DesktopScaleFactor;
    QSpinBox *kcfg_DesktopScaleFactorCustom;
    QLabel *deviceScaleFactorLabel;
    KComboBox *kcfg_DeviceScaleFactor;
    QLabel *layoutLabel;
    KComboBox *kcfg_KeyboardLayout;
    QLabel *soundLabel;
    KComboBox *kcfg_Sound;
    QLabel *shareMediaLabel;
    KUrlRequester *kcfg_ShareMedia;
    QLabel *shareSmartcardLabel;
    KLineEdit *kcfg_SmartcardName;
    QLabel *consoleModeLabel;
    QCheckBox *kcfg_ConsoleMode;
    QLabel *preventSessionLockLabel;
    QCheckBox *kcfg_PreventSessionLock;
    QWidget *securitySettingsTab;
    QVBoxLayout *vboxLayout;
    QFormLayout *securityFormLayout;
    QLabel *gSecurityLabel;
    QHBoxLayout *securityLayout;
    QCheckBox *kcfg_SecurityNLA;
    QCheckBox *kcfg_SecurityTLS;
    QCheckBox *kcfg_SecurityRDP;
    QCheckBox *kcfg_SecurityEXT;
    QLabel *TlsSecLevelLabel;
    KComboBox *kcfg_TlsSecLevel;
    QLabel *authPkgListLabel;
    KLineEdit *kcfg_AuthPkgList;
    QWidget *proxySettingsTab;
    QVBoxLayout *verticalLayout_4;
    QFormLayout *proxyFormLayout;
    QLabel *protocolLabel;
    QComboBox *kcfg_ProxyProtocol;
    KLineEdit *kcfg_ProxyUsername;
    QLabel *pPasswordLabel;
    KPasswordLineEdit *kcfg_ProxyPassword;
    QLabel *pUsernameLabel;
    QLabel *pHostLabel;
    KLineEdit *kcfg_ProxyHost;
    QWidget *gatewaySettingsTab;
    QVBoxLayout *verticalLayout_9;
    QFormLayout *gatewayFormLayout;
    QLabel *gServerLabel;
    QLabel *gUsernameLabel;
    QLabel *gPasswordLabel;
    KLineEdit *kcfg_GatewayServer;
    KLineEdit *kcfg_GatewayUsername;
    KPasswordLineEdit *kcfg_GatewayPassword;
    QLabel *gTransportTypeLabel;
    QComboBox *kcfg_GatewayTransportType;
    QLabel *gDomainLabel;
    KLineEdit *kcfg_GatewayDomain;

    void setupUi(QWidget *RdpPreferences)
    {
        if (RdpPreferences->objectName().isEmpty())
            RdpPreferences->setObjectName("RdpPreferences");
        RdpPreferences->resize(948, 500);
        gridLayout = new QGridLayout(RdpPreferences);
        gridLayout->setObjectName("gridLayout");
        settingsTabs = new QTabWidget(RdpPreferences);
        settingsTabs->setObjectName("settingsTabs");
        mainSettingsTab = new QWidget();
        mainSettingsTab->setObjectName("mainSettingsTab");
        gridLayoutMain = new QGridLayout(mainSettingsTab);
        gridLayoutMain->setObjectName("gridLayoutMain");
        resolutionLabel = new QLabel(mainSettingsTab);
        resolutionLabel->setObjectName("resolutionLabel");
        resolutionLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayoutMain->addWidget(resolutionLabel, 0, 0, 1, 1);

        kcfg_Resolution = new KComboBox(mainSettingsTab);
        kcfg_Resolution->addItem(QString());
        kcfg_Resolution->addItem(QString());
        kcfg_Resolution->addItem(QString());
        kcfg_Resolution->addItem(QString());
        kcfg_Resolution->addItem(QString());
        kcfg_Resolution->addItem(QString());
        kcfg_Resolution->setObjectName("kcfg_Resolution");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_Resolution->sizePolicy().hasHeightForWidth());
        kcfg_Resolution->setSizePolicy(sizePolicy);
        kcfg_Resolution->setMinimumSize(QSize(280, 0));

        gridLayoutMain->addWidget(kcfg_Resolution, 0, 1, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        widthLabel = new QLabel(mainSettingsTab);
        widthLabel->setObjectName("widthLabel");
        widthLabel->setEnabled(false);
        widthLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        hboxLayout->addWidget(widthLabel);

        kcfg_Width = new QSpinBox(mainSettingsTab);
        kcfg_Width->setObjectName("kcfg_Width");
        kcfg_Width->setEnabled(false);
        kcfg_Width->setMaximum(9999);
        kcfg_Width->setValue(800);

        hboxLayout->addWidget(kcfg_Width);

        heightLabel = new QLabel(mainSettingsTab);
        heightLabel->setObjectName("heightLabel");
        heightLabel->setEnabled(false);
        heightLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        hboxLayout->addWidget(heightLabel);

        kcfg_Height = new QSpinBox(mainSettingsTab);
        kcfg_Height->setObjectName("kcfg_Height");
        kcfg_Height->setEnabled(false);
        kcfg_Height->setMaximum(9999);
        kcfg_Height->setValue(600);

        hboxLayout->addWidget(kcfg_Height);


        gridLayoutMain->addLayout(hboxLayout, 1, 1, 1, 1);

        kcfg_ScaleToSize = new QCheckBox(mainSettingsTab);
        kcfg_ScaleToSize->setObjectName("kcfg_ScaleToSize");
        kcfg_ScaleToSize->setMinimumSize(QSize(0, 0));
        kcfg_ScaleToSize->setChecked(true);

        gridLayoutMain->addWidget(kcfg_ScaleToSize, 2, 1, 1, 1);

        accelerationLabel = new QLabel(mainSettingsTab);
        accelerationLabel->setObjectName("accelerationLabel");
        accelerationLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayoutMain->addWidget(accelerationLabel, 3, 0, 1, 1);

        kcfg_Acceleration = new KComboBox(mainSettingsTab);
        kcfg_Acceleration->addItem(QString());
        kcfg_Acceleration->addItem(QString());
        kcfg_Acceleration->addItem(QString());
        kcfg_Acceleration->addItem(QString());
        kcfg_Acceleration->setObjectName("kcfg_Acceleration");
        sizePolicy.setHeightForWidth(kcfg_Acceleration->sizePolicy().hasHeightForWidth());
        kcfg_Acceleration->setSizePolicy(sizePolicy);
        kcfg_Acceleration->setMinimumSize(QSize(280, 0));

        gridLayoutMain->addWidget(kcfg_Acceleration, 3, 1, 1, 1);

        colorDepthLabel = new QLabel(mainSettingsTab);
        colorDepthLabel->setObjectName("colorDepthLabel");
        colorDepthLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayoutMain->addWidget(colorDepthLabel, 4, 0, 1, 1);

        kcfg_ColorDepth = new KComboBox(mainSettingsTab);
        kcfg_ColorDepth->addItem(QString());
        kcfg_ColorDepth->addItem(QString());
        kcfg_ColorDepth->addItem(QString());
        kcfg_ColorDepth->addItem(QString());
        kcfg_ColorDepth->addItem(QString());
        kcfg_ColorDepth->setObjectName("kcfg_ColorDepth");
        sizePolicy.setHeightForWidth(kcfg_ColorDepth->sizePolicy().hasHeightForWidth());
        kcfg_ColorDepth->setSizePolicy(sizePolicy);
        kcfg_ColorDepth->setMinimumSize(QSize(280, 0));

        gridLayoutMain->addWidget(kcfg_ColorDepth, 4, 1, 1, 1);

        desktopScaleFactorLabel = new QLabel(mainSettingsTab);
        desktopScaleFactorLabel->setObjectName("desktopScaleFactorLabel");
        desktopScaleFactorLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayoutMain->addWidget(desktopScaleFactorLabel, 5, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        kcfg_DesktopScaleFactor = new KComboBox(mainSettingsTab);
        kcfg_DesktopScaleFactor->addItem(QString());
        kcfg_DesktopScaleFactor->addItem(QString());
        kcfg_DesktopScaleFactor->addItem(QString());
        kcfg_DesktopScaleFactor->setObjectName("kcfg_DesktopScaleFactor");
        sizePolicy.setHeightForWidth(kcfg_DesktopScaleFactor->sizePolicy().hasHeightForWidth());
        kcfg_DesktopScaleFactor->setSizePolicy(sizePolicy);

        hboxLayout1->addWidget(kcfg_DesktopScaleFactor);

        kcfg_DesktopScaleFactorCustom = new QSpinBox(mainSettingsTab);
        kcfg_DesktopScaleFactorCustom->setObjectName("kcfg_DesktopScaleFactorCustom");
        kcfg_DesktopScaleFactorCustom->setEnabled(false);
        sizePolicy.setHeightForWidth(kcfg_DesktopScaleFactorCustom->sizePolicy().hasHeightForWidth());
        kcfg_DesktopScaleFactorCustom->setSizePolicy(sizePolicy);
        kcfg_DesktopScaleFactorCustom->setMinimum(100);
        kcfg_DesktopScaleFactorCustom->setMaximum(500);
        kcfg_DesktopScaleFactorCustom->setValue(100);

        hboxLayout1->addWidget(kcfg_DesktopScaleFactorCustom);


        gridLayoutMain->addLayout(hboxLayout1, 5, 1, 1, 1);

        deviceScaleFactorLabel = new QLabel(mainSettingsTab);
        deviceScaleFactorLabel->setObjectName("deviceScaleFactorLabel");
        deviceScaleFactorLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayoutMain->addWidget(deviceScaleFactorLabel, 6, 0, 1, 1);

        kcfg_DeviceScaleFactor = new KComboBox(mainSettingsTab);
        kcfg_DeviceScaleFactor->addItem(QString());
        kcfg_DeviceScaleFactor->addItem(QString());
        kcfg_DeviceScaleFactor->addItem(QString());
        kcfg_DeviceScaleFactor->addItem(QString());
        kcfg_DeviceScaleFactor->setObjectName("kcfg_DeviceScaleFactor");
        sizePolicy.setHeightForWidth(kcfg_DeviceScaleFactor->sizePolicy().hasHeightForWidth());
        kcfg_DeviceScaleFactor->setSizePolicy(sizePolicy);
        kcfg_DeviceScaleFactor->setMinimumSize(QSize(280, 0));

        gridLayoutMain->addWidget(kcfg_DeviceScaleFactor, 6, 1, 1, 1);

        layoutLabel = new QLabel(mainSettingsTab);
        layoutLabel->setObjectName("layoutLabel");
        layoutLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayoutMain->addWidget(layoutLabel, 7, 0, 1, 1);

        kcfg_KeyboardLayout = new KComboBox(mainSettingsTab);
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->addItem(QString());
        kcfg_KeyboardLayout->setObjectName("kcfg_KeyboardLayout");
        sizePolicy.setHeightForWidth(kcfg_KeyboardLayout->sizePolicy().hasHeightForWidth());
        kcfg_KeyboardLayout->setSizePolicy(sizePolicy);
        kcfg_KeyboardLayout->setMinimumSize(QSize(280, 0));

        gridLayoutMain->addWidget(kcfg_KeyboardLayout, 7, 1, 1, 1);

        soundLabel = new QLabel(mainSettingsTab);
        soundLabel->setObjectName("soundLabel");
        soundLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayoutMain->addWidget(soundLabel, 8, 0, 1, 1);

        kcfg_Sound = new KComboBox(mainSettingsTab);
        kcfg_Sound->addItem(QString());
        kcfg_Sound->addItem(QString());
        kcfg_Sound->addItem(QString());
        kcfg_Sound->setObjectName("kcfg_Sound");
        sizePolicy.setHeightForWidth(kcfg_Sound->sizePolicy().hasHeightForWidth());
        kcfg_Sound->setSizePolicy(sizePolicy);
        kcfg_Sound->setMinimumSize(QSize(280, 0));

        gridLayoutMain->addWidget(kcfg_Sound, 8, 1, 1, 1);

        shareMediaLabel = new QLabel(mainSettingsTab);
        shareMediaLabel->setObjectName("shareMediaLabel");
        shareMediaLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayoutMain->addWidget(shareMediaLabel, 9, 0, 1, 1);

        kcfg_ShareMedia = new KUrlRequester(mainSettingsTab);
        kcfg_ShareMedia->setObjectName("kcfg_ShareMedia");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_ShareMedia->sizePolicy().hasHeightForWidth());
        kcfg_ShareMedia->setSizePolicy(sizePolicy1);
        kcfg_ShareMedia->setMode(KFile::Mode::Directory|KFile::Mode::ExistingOnly|KFile::Mode::LocalOnly);
        kcfg_ShareMedia->setAcceptMode(QFileDialog::AcceptMode::AcceptOpen);

        gridLayoutMain->addWidget(kcfg_ShareMedia, 9, 1, 1, 1);

        shareSmartcardLabel = new QLabel(mainSettingsTab);
        shareSmartcardLabel->setObjectName("shareSmartcardLabel");
        shareSmartcardLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayoutMain->addWidget(shareSmartcardLabel, 10, 0, 1, 1);

        kcfg_SmartcardName = new KLineEdit(mainSettingsTab);
        kcfg_SmartcardName->setObjectName("kcfg_SmartcardName");

        gridLayoutMain->addWidget(kcfg_SmartcardName, 10, 1, 1, 1);

        consoleModeLabel = new QLabel(mainSettingsTab);
        consoleModeLabel->setObjectName("consoleModeLabel");
        consoleModeLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayoutMain->addWidget(consoleModeLabel, 11, 0, 1, 1);

        kcfg_ConsoleMode = new QCheckBox(mainSettingsTab);
        kcfg_ConsoleMode->setObjectName("kcfg_ConsoleMode");

        gridLayoutMain->addWidget(kcfg_ConsoleMode, 11, 1, 1, 1);

        preventSessionLockLabel = new QLabel(mainSettingsTab);
        preventSessionLockLabel->setObjectName("preventSessionLockLabel");
        preventSessionLockLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayoutMain->addWidget(preventSessionLockLabel, 12, 0, 1, 1);

        kcfg_PreventSessionLock = new QCheckBox(mainSettingsTab);
        kcfg_PreventSessionLock->setObjectName("kcfg_PreventSessionLock");

        gridLayoutMain->addWidget(kcfg_PreventSessionLock, 12, 1, 1, 1);

        settingsTabs->addTab(mainSettingsTab, QString());
        securitySettingsTab = new QWidget();
        securitySettingsTab->setObjectName("securitySettingsTab");
        vboxLayout = new QVBoxLayout(securitySettingsTab);
        vboxLayout->setObjectName("vboxLayout");
        securityFormLayout = new QFormLayout();
        securityFormLayout->setObjectName("securityFormLayout");
        gSecurityLabel = new QLabel(securitySettingsTab);
        gSecurityLabel->setObjectName("gSecurityLabel");
        gSecurityLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        securityFormLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, gSecurityLabel);

        securityLayout = new QHBoxLayout();
        securityLayout->setObjectName("securityLayout");
        kcfg_SecurityNLA = new QCheckBox(securitySettingsTab);
        kcfg_SecurityNLA->setObjectName("kcfg_SecurityNLA");

        securityLayout->addWidget(kcfg_SecurityNLA);

        kcfg_SecurityTLS = new QCheckBox(securitySettingsTab);
        kcfg_SecurityTLS->setObjectName("kcfg_SecurityTLS");

        securityLayout->addWidget(kcfg_SecurityTLS);

        kcfg_SecurityRDP = new QCheckBox(securitySettingsTab);
        kcfg_SecurityRDP->setObjectName("kcfg_SecurityRDP");

        securityLayout->addWidget(kcfg_SecurityRDP);

        kcfg_SecurityEXT = new QCheckBox(securitySettingsTab);
        kcfg_SecurityEXT->setObjectName("kcfg_SecurityEXT");

        securityLayout->addWidget(kcfg_SecurityEXT);


        securityFormLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, securityLayout);

        TlsSecLevelLabel = new QLabel(securitySettingsTab);
        TlsSecLevelLabel->setObjectName("TlsSecLevelLabel");
        TlsSecLevelLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        securityFormLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, TlsSecLevelLabel);

        kcfg_TlsSecLevel = new KComboBox(securitySettingsTab);
        kcfg_TlsSecLevel->addItem(QString());
        kcfg_TlsSecLevel->addItem(QString());
        kcfg_TlsSecLevel->addItem(QString());
        kcfg_TlsSecLevel->addItem(QString());
        kcfg_TlsSecLevel->addItem(QString());
        kcfg_TlsSecLevel->addItem(QString());
        kcfg_TlsSecLevel->setObjectName("kcfg_TlsSecLevel");
        sizePolicy.setHeightForWidth(kcfg_TlsSecLevel->sizePolicy().hasHeightForWidth());
        kcfg_TlsSecLevel->setSizePolicy(sizePolicy);
        kcfg_TlsSecLevel->setMinimumSize(QSize(280, 0));

        securityFormLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_TlsSecLevel);

        authPkgListLabel = new QLabel(securitySettingsTab);
        authPkgListLabel->setObjectName("authPkgListLabel");
        authPkgListLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        securityFormLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, authPkgListLabel);

        kcfg_AuthPkgList = new KLineEdit(securitySettingsTab);
        kcfg_AuthPkgList->setObjectName("kcfg_AuthPkgList");

        securityFormLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_AuthPkgList);


        vboxLayout->addLayout(securityFormLayout);

        settingsTabs->addTab(securitySettingsTab, QString());
        proxySettingsTab = new QWidget();
        proxySettingsTab->setObjectName("proxySettingsTab");
        verticalLayout_4 = new QVBoxLayout(proxySettingsTab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        proxyFormLayout = new QFormLayout();
        proxyFormLayout->setObjectName("proxyFormLayout");
        protocolLabel = new QLabel(proxySettingsTab);
        protocolLabel->setObjectName("protocolLabel");

        proxyFormLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, protocolLabel);

        kcfg_ProxyProtocol = new QComboBox(proxySettingsTab);
        kcfg_ProxyProtocol->addItem(QString());
        kcfg_ProxyProtocol->addItem(QString());
        kcfg_ProxyProtocol->setObjectName("kcfg_ProxyProtocol");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(kcfg_ProxyProtocol->sizePolicy().hasHeightForWidth());
        kcfg_ProxyProtocol->setSizePolicy(sizePolicy2);

        proxyFormLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_ProxyProtocol);

        kcfg_ProxyUsername = new KLineEdit(proxySettingsTab);
        kcfg_ProxyUsername->setObjectName("kcfg_ProxyUsername");

        proxyFormLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_ProxyUsername);

        pPasswordLabel = new QLabel(proxySettingsTab);
        pPasswordLabel->setObjectName("pPasswordLabel");

        proxyFormLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, pPasswordLabel);

        kcfg_ProxyPassword = new KPasswordLineEdit(proxySettingsTab);
        kcfg_ProxyPassword->setObjectName("kcfg_ProxyPassword");

        proxyFormLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_ProxyPassword);

        pUsernameLabel = new QLabel(proxySettingsTab);
        pUsernameLabel->setObjectName("pUsernameLabel");

        proxyFormLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, pUsernameLabel);

        pHostLabel = new QLabel(proxySettingsTab);
        pHostLabel->setObjectName("pHostLabel");

        proxyFormLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, pHostLabel);

        kcfg_ProxyHost = new KLineEdit(proxySettingsTab);
        kcfg_ProxyHost->setObjectName("kcfg_ProxyHost");

        proxyFormLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_ProxyHost);


        verticalLayout_4->addLayout(proxyFormLayout);

        settingsTabs->addTab(proxySettingsTab, QString());
        gatewaySettingsTab = new QWidget();
        gatewaySettingsTab->setObjectName("gatewaySettingsTab");
        verticalLayout_9 = new QVBoxLayout(gatewaySettingsTab);
        verticalLayout_9->setObjectName("verticalLayout_9");
        gatewayFormLayout = new QFormLayout();
        gatewayFormLayout->setObjectName("gatewayFormLayout");
        gServerLabel = new QLabel(gatewaySettingsTab);
        gServerLabel->setObjectName("gServerLabel");

        gatewayFormLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, gServerLabel);

        gUsernameLabel = new QLabel(gatewaySettingsTab);
        gUsernameLabel->setObjectName("gUsernameLabel");

        gatewayFormLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, gUsernameLabel);

        gPasswordLabel = new QLabel(gatewaySettingsTab);
        gPasswordLabel->setObjectName("gPasswordLabel");

        gatewayFormLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, gPasswordLabel);

        kcfg_GatewayServer = new KLineEdit(gatewaySettingsTab);
        kcfg_GatewayServer->setObjectName("kcfg_GatewayServer");

        gatewayFormLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_GatewayServer);

        kcfg_GatewayUsername = new KLineEdit(gatewaySettingsTab);
        kcfg_GatewayUsername->setObjectName("kcfg_GatewayUsername");

        gatewayFormLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_GatewayUsername);

        kcfg_GatewayPassword = new KPasswordLineEdit(gatewaySettingsTab);
        kcfg_GatewayPassword->setObjectName("kcfg_GatewayPassword");

        gatewayFormLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_GatewayPassword);

        gTransportTypeLabel = new QLabel(gatewaySettingsTab);
        gTransportTypeLabel->setObjectName("gTransportTypeLabel");

        gatewayFormLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, gTransportTypeLabel);

        kcfg_GatewayTransportType = new QComboBox(gatewaySettingsTab);
        kcfg_GatewayTransportType->addItem(QString());
        kcfg_GatewayTransportType->addItem(QString());
        kcfg_GatewayTransportType->addItem(QString());
        kcfg_GatewayTransportType->setObjectName("kcfg_GatewayTransportType");
        sizePolicy2.setHeightForWidth(kcfg_GatewayTransportType->sizePolicy().hasHeightForWidth());
        kcfg_GatewayTransportType->setSizePolicy(sizePolicy2);

        gatewayFormLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_GatewayTransportType);

        gDomainLabel = new QLabel(gatewaySettingsTab);
        gDomainLabel->setObjectName("gDomainLabel");

        gatewayFormLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, gDomainLabel);

        kcfg_GatewayDomain = new KLineEdit(gatewaySettingsTab);
        kcfg_GatewayDomain->setObjectName("kcfg_GatewayDomain");

        gatewayFormLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_GatewayDomain);


        verticalLayout_9->addLayout(gatewayFormLayout);

        settingsTabs->addTab(gatewaySettingsTab, QString());

        gridLayout->addWidget(settingsTabs, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        widthLabel->setBuddy(kcfg_Width);
        heightLabel->setBuddy(kcfg_Height);
        colorDepthLabel->setBuddy(kcfg_ColorDepth);
        desktopScaleFactorLabel->setBuddy(kcfg_DesktopScaleFactorCustom);
        deviceScaleFactorLabel->setBuddy(kcfg_DeviceScaleFactor);
        layoutLabel->setBuddy(kcfg_KeyboardLayout);
        soundLabel->setBuddy(kcfg_Sound);
        TlsSecLevelLabel->setBuddy(kcfg_TlsSecLevel);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_Width, kcfg_Height);
        QWidget::setTabOrder(kcfg_Height, kcfg_ColorDepth);
        QWidget::setTabOrder(kcfg_ColorDepth, kcfg_KeyboardLayout);

        retranslateUi(RdpPreferences);

        settingsTabs->setCurrentIndex(0);
        kcfg_Resolution->setCurrentIndex(0);
        kcfg_KeyboardLayout->setCurrentIndex(7);


        QMetaObject::connectSlotsByName(RdpPreferences);
    } // setupUi

    void retranslateUi(QWidget *RdpPreferences)
    {
        resolutionLabel->setText(tr2i18n("Resolution", nullptr));
        kcfg_Resolution->setItemText(0, tr2i18n("Small (1280x720)", nullptr));
        kcfg_Resolution->setItemText(1, tr2i18n("Medium (1600x900)", nullptr));
        kcfg_Resolution->setItemText(2, tr2i18n("Large (1920x1080)", nullptr));
        kcfg_Resolution->setItemText(3, tr2i18n("Current Window Size", nullptr));
        kcfg_Resolution->setItemText(4, tr2i18n("Current Screen Resolution", nullptr));
        kcfg_Resolution->setItemText(5, tr2i18n("Custom Resolution (\342\200\246)", nullptr));

#if QT_CONFIG(whatsthis)
        kcfg_Resolution->setWhatsThis(tr2i18n("Here you can specify the resolution of the remote desktop. This resolution determines the size of the desktop that will be presented to you.", nullptr));
#endif // QT_CONFIG(whatsthis)
        widthLabel->setText(tr2i18n("&Width:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_Width->setWhatsThis(tr2i18n("This is the width of the remote desktop. You can only change this value manually if you select Custom as desktop resolution above.", nullptr));
#endif // QT_CONFIG(whatsthis)
        heightLabel->setText(tr2i18n("H&eight:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_Height->setWhatsThis(tr2i18n("This is the height of the remote desktop. You can only change this value manually if you select Custom as desktop resolution above.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ScaleToSize->setText(tr2i18n("Scale window contents to match resolution", nullptr));
        accelerationLabel->setText(tr2i18n("Acceleration:", nullptr));
        kcfg_Acceleration->setItemText(0, tr2i18n("Use Best Available", "Use best acceleration supported by both the server and krdc"));
        kcfg_Acceleration->setItemText(1, tr2i18n("Force H.264", nullptr));
        kcfg_Acceleration->setItemText(2, tr2i18n("Force RemoteFX", nullptr));
        kcfg_Acceleration->setItemText(3, tr2i18n("Disable All Acceleration", nullptr));

        colorDepthLabel->setText(tr2i18n("Color &depth:", nullptr));
        kcfg_ColorDepth->setItemText(0, tr2i18n("Use Best Available", "Use best color depth supported by both the server and krdc"));
        kcfg_ColorDepth->setItemText(1, tr2i18n("True Color with Alpha (32 Bit)", nullptr));
        kcfg_ColorDepth->setItemText(2, tr2i18n("True Color (24 Bit)", nullptr));
        kcfg_ColorDepth->setItemText(3, tr2i18n("High Color (16 Bit)", nullptr));
        kcfg_ColorDepth->setItemText(4, tr2i18n("Low Color (8 Bit)", nullptr));

        desktopScaleFactorLabel->setText(tr2i18n("Desktop scale factor:", nullptr));
        kcfg_DesktopScaleFactor->setItemText(0, tr2i18n("Auto", nullptr));
        kcfg_DesktopScaleFactor->setItemText(1, tr2i18n("Do not scale", nullptr));
        kcfg_DesktopScaleFactor->setItemText(2, tr2i18n("Custom", nullptr));

        deviceScaleFactorLabel->setText(tr2i18n("Device scale factor:", nullptr));
        kcfg_DeviceScaleFactor->setItemText(0, tr2i18n("Auto", nullptr));
        kcfg_DeviceScaleFactor->setItemText(1, tr2i18n("100", nullptr));
        kcfg_DeviceScaleFactor->setItemText(2, tr2i18n("140", nullptr));
        kcfg_DeviceScaleFactor->setItemText(3, tr2i18n("180", nullptr));

        layoutLabel->setText(tr2i18n("&Keyboard layout:", nullptr));
        kcfg_KeyboardLayout->setItemText(0, tr2i18n("Arabic (ar)", nullptr));
        kcfg_KeyboardLayout->setItemText(1, tr2i18n("Czech (cs)", nullptr));
        kcfg_KeyboardLayout->setItemText(2, tr2i18n("Danish (da)", nullptr));
        kcfg_KeyboardLayout->setItemText(3, tr2i18n("German (de)", nullptr));
        kcfg_KeyboardLayout->setItemText(4, tr2i18n("Swiss German (de-ch)", nullptr));
        kcfg_KeyboardLayout->setItemText(5, tr2i18n("American Dvorak (en-dv)", nullptr));
        kcfg_KeyboardLayout->setItemText(6, tr2i18n("British English (en-gb)", nullptr));
        kcfg_KeyboardLayout->setItemText(7, tr2i18n("US English (en-us)", nullptr));
        kcfg_KeyboardLayout->setItemText(8, tr2i18n("Spanish (es)", nullptr));
        kcfg_KeyboardLayout->setItemText(9, tr2i18n("Estonian (et)", nullptr));
        kcfg_KeyboardLayout->setItemText(10, tr2i18n("Finnish (fi)", nullptr));
        kcfg_KeyboardLayout->setItemText(11, tr2i18n("Faroese (fo)", nullptr));
        kcfg_KeyboardLayout->setItemText(12, tr2i18n("French (fr)", nullptr));
        kcfg_KeyboardLayout->setItemText(13, tr2i18n("Belgian (fr-be)", nullptr));
        kcfg_KeyboardLayout->setItemText(14, tr2i18n("French Canadian (fr-ca)", nullptr));
        kcfg_KeyboardLayout->setItemText(15, tr2i18n("Swiss French (fr-ch)", nullptr));
        kcfg_KeyboardLayout->setItemText(16, tr2i18n("Hebrew (he)", nullptr));
        kcfg_KeyboardLayout->setItemText(17, tr2i18n("Croatian (hr)", nullptr));
        kcfg_KeyboardLayout->setItemText(18, tr2i18n("Hungarian (hu)", nullptr));
        kcfg_KeyboardLayout->setItemText(19, tr2i18n("Icelandic (is)", nullptr));
        kcfg_KeyboardLayout->setItemText(20, tr2i18n("Italian (it)", nullptr));
        kcfg_KeyboardLayout->setItemText(21, tr2i18n("Japanese (ja)", nullptr));
        kcfg_KeyboardLayout->setItemText(22, tr2i18n("Korean (ko)", nullptr));
        kcfg_KeyboardLayout->setItemText(23, tr2i18n("Lithuanian (lt)", nullptr));
        kcfg_KeyboardLayout->setItemText(24, tr2i18n("Latvian (lv)", nullptr));
        kcfg_KeyboardLayout->setItemText(25, tr2i18n("Macedonian (mk)", nullptr));
        kcfg_KeyboardLayout->setItemText(26, tr2i18n("Dutch (nl)", nullptr));
        kcfg_KeyboardLayout->setItemText(27, tr2i18n("Belgian Dutch (nl-be)", nullptr));
        kcfg_KeyboardLayout->setItemText(28, tr2i18n("Norwegian (no)", nullptr));
        kcfg_KeyboardLayout->setItemText(29, tr2i18n("Polish (pl)", nullptr));
        kcfg_KeyboardLayout->setItemText(30, tr2i18n("Portuguese (pt)", nullptr));
        kcfg_KeyboardLayout->setItemText(31, tr2i18n("Brazilian (pt-br)", nullptr));
        kcfg_KeyboardLayout->setItemText(32, tr2i18n("Russian (ru)", nullptr));
        kcfg_KeyboardLayout->setItemText(33, tr2i18n("Slovenian (sl)", nullptr));
        kcfg_KeyboardLayout->setItemText(34, tr2i18n("Swedish (sv)", nullptr));
        kcfg_KeyboardLayout->setItemText(35, tr2i18n("Thai (th)", nullptr));
        kcfg_KeyboardLayout->setItemText(36, tr2i18n("Turkish (tr)", nullptr));

#if QT_CONFIG(whatsthis)
        kcfg_KeyboardLayout->setWhatsThis(tr2i18n("Use this to specify your keyboard layout. This layout setting is used to send the correct keyboard codes to the server.", nullptr));
#endif // QT_CONFIG(whatsthis)
        soundLabel->setText(tr2i18n("Sound:", "label for soundsettings in preferences dialog"));
        kcfg_Sound->setItemText(0, tr2i18n("On This Computer", nullptr));
        kcfg_Sound->setItemText(1, tr2i18n("On Remote Computer", nullptr));
        kcfg_Sound->setItemText(2, tr2i18n("Disable Sound", nullptr));

        shareMediaLabel->setText(tr2i18n("Share Media:", nullptr));
        shareSmartcardLabel->setText(tr2i18n("Share Smartcard:", nullptr));
        consoleModeLabel->setText(tr2i18n("Alternate Session Type:", nullptr));
        kcfg_ConsoleMode->setText(tr2i18n("Admin (or console) session", nullptr));
        preventSessionLockLabel->setText(tr2i18n("Session lock:", nullptr));
        kcfg_PreventSessionLock->setText(tr2i18n("Prevent remote session lock", nullptr));
        settingsTabs->setTabText(settingsTabs->indexOf(mainSettingsTab), tr2i18n("General", nullptr));
        gSecurityLabel->setText(tr2i18n("Security:", nullptr));
        kcfg_SecurityNLA->setText(tr2i18n("NLA", nullptr));
        kcfg_SecurityTLS->setText(tr2i18n("TLS", nullptr));
        kcfg_SecurityRDP->setText(tr2i18n("RDP", nullptr));
        kcfg_SecurityEXT->setText(tr2i18n("Ext", nullptr));
        TlsSecLevelLabel->setText(tr2i18n("TLS security level:", nullptr));
        kcfg_TlsSecLevel->setItemText(0, tr2i18n("any", nullptr));
        kcfg_TlsSecLevel->setItemText(1, tr2i18n("80 bit", nullptr));
        kcfg_TlsSecLevel->setItemText(2, tr2i18n("112 bit", nullptr));
        kcfg_TlsSecLevel->setItemText(3, tr2i18n("128 bit", nullptr));
        kcfg_TlsSecLevel->setItemText(4, tr2i18n("192 bit", nullptr));
        kcfg_TlsSecLevel->setItemText(5, tr2i18n("256 bit", nullptr));

        authPkgListLabel->setText(tr2i18n("Authentication Package List:", nullptr));
        settingsTabs->setTabText(settingsTabs->indexOf(securitySettingsTab), tr2i18n("Security", nullptr));
        protocolLabel->setText(tr2i18n("Protocol:", nullptr));
        kcfg_ProxyProtocol->setItemText(0, tr2i18n("HTTP", nullptr));
        kcfg_ProxyProtocol->setItemText(1, tr2i18n("SOCKS", nullptr));

        pPasswordLabel->setText(tr2i18n("Password:", nullptr));
        pUsernameLabel->setText(tr2i18n("Username:", nullptr));
        pHostLabel->setText(tr2i18n("Server:", nullptr));
        kcfg_ProxyHost->setPlaceholderText(tr2i18n("host:port", nullptr));
        settingsTabs->setTabText(settingsTabs->indexOf(proxySettingsTab), tr2i18n("Proxy", nullptr));
        gServerLabel->setText(tr2i18n("Server:", nullptr));
        gUsernameLabel->setText(tr2i18n("Username:", nullptr));
        gPasswordLabel->setText(tr2i18n("Password:", nullptr));
        kcfg_GatewayServer->setPlaceholderText(tr2i18n("host:port", nullptr));
        gTransportTypeLabel->setText(tr2i18n("Transport type:", nullptr));
        kcfg_GatewayTransportType->setItemText(0, tr2i18n("Auto", nullptr));
        kcfg_GatewayTransportType->setItemText(1, tr2i18n("HTTP", nullptr));
        kcfg_GatewayTransportType->setItemText(2, tr2i18n("RPC", nullptr));

        gDomainLabel->setText(tr2i18n("Domain:", nullptr));
        settingsTabs->setTabText(settingsTabs->indexOf(gatewaySettingsTab), tr2i18n("Gateway", nullptr));
        (void)RdpPreferences;
    } // retranslateUi

};

namespace Ui {
    class RdpPreferences: public Ui_RdpPreferences {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RDPPREFERENCES_H

