/****************************************************************************
** Meta object code from reading C++ file 'remoteview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../krdc-26.04.3/core/remoteview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'remoteview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10RemoteViewE_t {};
} // unnamed namespace

template <> constexpr inline auto RemoteView::qt_create_metaobjectdata<qt_meta_tag_ZN10RemoteViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RemoteView",
        "framebufferSizeChanged",
        "",
        "w",
        "h",
        "connected",
        "disconnected",
        "disconnectedError",
        "errorMessage",
        "title",
        "message",
        "statusChanged",
        "RemoteView::RemoteStatus",
        "s",
        "showingPasswordDialog",
        "b",
        "mouseStateChanged",
        "x",
        "y",
        "buttonMask",
        "enableScaling",
        "scale",
        "setScaleFactor",
        "factor",
        "setViewOnly",
        "viewOnly",
        "setGrabAllKeys",
        "grabAllKeys",
        "switchFullscreen",
        "on",
        "keyEvent",
        "QKeyEvent*",
        "event",
        "scaleResize",
        "localClipboardChanged",
        "remoteClipboardChanged",
        "QMimeData*",
        "data",
        "sshRequestPassword",
        "SshTunnelThread::PasswordRequestFlags",
        "flags",
        "sshErrorMessage",
        "Quality",
        "Unknown",
        "High",
        "Medium",
        "Low",
        "LocalCursorState",
        "CursorOn",
        "CursorOff",
        "CursorAuto",
        "RemoteStatus",
        "Connecting",
        "Authenticating",
        "Preparing",
        "Connected",
        "Disconnecting",
        "Disconnected",
        "ErrorCode",
        "None",
        "Internal",
        "Connection",
        "Protocol",
        "IO",
        "Name",
        "NoServer",
        "ServerBlocked",
        "Authentication"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'framebufferSizeChanged'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'connected'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disconnected'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disconnectedError'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorMessage'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(RemoteView::RemoteStatus)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'showingPasswordDialog'
        QtMocHelpers::SignalData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Signal 'mouseStateChanged'
        QtMocHelpers::SignalData<void(int, int, int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 19 },
        }}),
        // Slot 'enableScaling'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'setScaleFactor'
        QtMocHelpers::SlotData<void(float)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 23 },
        }}),
        // Slot 'setViewOnly'
        QtMocHelpers::SlotData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'setGrabAllKeys'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'switchFullscreen'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'keyEvent'
        QtMocHelpers::SlotData<void(QKeyEvent *)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'scaleResize'
        QtMocHelpers::SlotData<void(int, int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'localClipboardChanged'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'remoteClipboardChanged'
        QtMocHelpers::SlotData<void(QMimeData *)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'sshRequestPassword'
        QtMocHelpers::SlotData<void(SshTunnelThread::PasswordRequestFlags)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 40 },
        }}),
        // Slot 'sshErrorMessage'
        QtMocHelpers::SlotData<void(const QString &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Quality'
        QtMocHelpers::EnumData<enum Quality>(42, 42, QMC::EnumFlags{}).add({
            {   43, Quality::Unknown },
            {   44, Quality::High },
            {   45, Quality::Medium },
            {   46, Quality::Low },
        }),
        // enum 'LocalCursorState'
        QtMocHelpers::EnumData<enum LocalCursorState>(47, 47, QMC::EnumFlags{}).add({
            {   48, LocalCursorState::CursorOn },
            {   49, LocalCursorState::CursorOff },
            {   50, LocalCursorState::CursorAuto },
        }),
        // enum 'RemoteStatus'
        QtMocHelpers::EnumData<enum RemoteStatus>(51, 51, QMC::EnumFlags{}).add({
            {   52, RemoteStatus::Connecting },
            {   53, RemoteStatus::Authenticating },
            {   54, RemoteStatus::Preparing },
            {   55, RemoteStatus::Connected },
            {   56, RemoteStatus::Disconnecting },
            {   57, RemoteStatus::Disconnected },
        }),
        // enum 'ErrorCode'
        QtMocHelpers::EnumData<enum ErrorCode>(58, 58, QMC::EnumFlags{}).add({
            {   59, ErrorCode::None },
            {   60, ErrorCode::Internal },
            {   61, ErrorCode::Connection },
            {   62, ErrorCode::Protocol },
            {   63, ErrorCode::IO },
            {   64, ErrorCode::Name },
            {   65, ErrorCode::NoServer },
            {   66, ErrorCode::ServerBlocked },
            {   67, ErrorCode::Authentication },
        }),
    };
    return QtMocHelpers::metaObjectData<RemoteView, qt_meta_tag_ZN10RemoteViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RemoteView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10RemoteViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10RemoteViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10RemoteViewE_t>.metaTypes,
    nullptr
} };

void RemoteView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RemoteView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->framebufferSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->connected(); break;
        case 2: _t->disconnected(); break;
        case 3: _t->disconnectedError(); break;
        case 4: _t->errorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<RemoteView::RemoteStatus>>(_a[1]))); break;
        case 6: _t->showingPasswordDialog((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->mouseStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 8: _t->enableScaling((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->setScaleFactor((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 10: _t->setViewOnly((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->setGrabAllKeys((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->switchFullscreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->keyEvent((*reinterpret_cast<std::add_pointer_t<QKeyEvent*>>(_a[1]))); break;
        case 14: _t->scaleResize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: _t->localClipboardChanged(); break;
        case 16: _t->remoteClipboardChanged((*reinterpret_cast<std::add_pointer_t<QMimeData*>>(_a[1]))); break;
        case 17: _t->sshRequestPassword((*reinterpret_cast<std::add_pointer_t<SshTunnelThread::PasswordRequestFlags>>(_a[1]))); break;
        case 18: _t->sshErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RemoteView::*)(int , int )>(_a, &RemoteView::framebufferSizeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RemoteView::*)()>(_a, &RemoteView::connected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RemoteView::*)()>(_a, &RemoteView::disconnected, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RemoteView::*)()>(_a, &RemoteView::disconnectedError, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (RemoteView::*)(const QString & , const QString & )>(_a, &RemoteView::errorMessage, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (RemoteView::*)(RemoteView::RemoteStatus )>(_a, &RemoteView::statusChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (RemoteView::*)(bool )>(_a, &RemoteView::showingPasswordDialog, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (RemoteView::*)(int , int , int )>(_a, &RemoteView::mouseStateChanged, 7))
            return;
    }
}

const QMetaObject *RemoteView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RemoteView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10RemoteViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int RemoteView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void RemoteView::framebufferSizeChanged(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void RemoteView::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void RemoteView::disconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void RemoteView::disconnectedError()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void RemoteView::errorMessage(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void RemoteView::statusChanged(RemoteView::RemoteStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void RemoteView::showingPasswordDialog(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void RemoteView::mouseStateChanged(int _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
