/********************************************************************************
** Form generated from reading UI file 'vncpreferences.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VNCPREFERENCES_H
#define UI_VNCPREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_VncPreferences
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *vncGroupBox;
    QFormLayout *formLayout;
    QLabel *connectionLabel;
    KComboBox *kcfg_Quality;
    QVBoxLayout *vboxLayout;
    QCheckBox *kcfg_Scaling;
    QLabel *resolutionDummyLabel;
    QVBoxLayout *vboxLayout1;
    KComboBox *resolutionComboBox;
    QHBoxLayout *hboxLayout;
    QLabel *widthLabel;
    QSpinBox *kcfg_ScalingWidth;
    QLabel *heightLabel;
    QSpinBox *kcfg_ScalingHeight;
    QHBoxLayout *sshTunnelLayout;
    QCheckBox *dont_copy_passwords;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *VncPreferences)
    {
        if (VncPreferences->objectName().isEmpty())
            VncPreferences->setObjectName("VncPreferences");
        VncPreferences->resize(440, 396);
        verticalLayout = new QVBoxLayout(VncPreferences);
        verticalLayout->setObjectName("verticalLayout");
        vncGroupBox = new QGroupBox(VncPreferences);
        vncGroupBox->setObjectName("vncGroupBox");
        formLayout = new QFormLayout(vncGroupBox);
        formLayout->setObjectName("formLayout");
        connectionLabel = new QLabel(vncGroupBox);
        connectionLabel->setObjectName("connectionLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, connectionLabel);

        kcfg_Quality = new KComboBox(vncGroupBox);
        kcfg_Quality->addItem(QString());
        kcfg_Quality->addItem(QString());
        kcfg_Quality->addItem(QString());
        kcfg_Quality->setObjectName("kcfg_Quality");
        kcfg_Quality->setMinimumSize(QSize(280, 0));

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_Quality);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        kcfg_Scaling = new QCheckBox(vncGroupBox);
        kcfg_Scaling->setObjectName("kcfg_Scaling");

        vboxLayout->addWidget(kcfg_Scaling);

        resolutionDummyLabel = new QLabel(vncGroupBox);
        resolutionDummyLabel->setObjectName("resolutionDummyLabel");

        vboxLayout->addWidget(resolutionDummyLabel);


        formLayout->setLayout(2, QFormLayout::ItemRole::LabelRole, vboxLayout);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        resolutionComboBox = new KComboBox(vncGroupBox);
        resolutionComboBox->addItem(QString());
        resolutionComboBox->addItem(QString());
        resolutionComboBox->addItem(QString());
        resolutionComboBox->addItem(QString());
        resolutionComboBox->addItem(QString());
        resolutionComboBox->addItem(QString());
        resolutionComboBox->addItem(QString());
        resolutionComboBox->setObjectName("resolutionComboBox");
        resolutionComboBox->setEnabled(false);
        resolutionComboBox->setMinimumSize(QSize(280, 0));

        vboxLayout1->addWidget(resolutionComboBox);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        widthLabel = new QLabel(vncGroupBox);
        widthLabel->setObjectName("widthLabel");
        widthLabel->setEnabled(false);
        widthLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        hboxLayout->addWidget(widthLabel);

        kcfg_ScalingWidth = new QSpinBox(vncGroupBox);
        kcfg_ScalingWidth->setObjectName("kcfg_ScalingWidth");
        kcfg_ScalingWidth->setEnabled(false);
        kcfg_ScalingWidth->setMaximum(9999);
        kcfg_ScalingWidth->setValue(800);

        hboxLayout->addWidget(kcfg_ScalingWidth);

        heightLabel = new QLabel(vncGroupBox);
        heightLabel->setObjectName("heightLabel");
        heightLabel->setEnabled(false);
        heightLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        hboxLayout->addWidget(heightLabel);

        kcfg_ScalingHeight = new QSpinBox(vncGroupBox);
        kcfg_ScalingHeight->setObjectName("kcfg_ScalingHeight");
        kcfg_ScalingHeight->setEnabled(false);
        kcfg_ScalingHeight->setMaximum(9999);
        kcfg_ScalingHeight->setValue(600);

        hboxLayout->addWidget(kcfg_ScalingHeight);


        vboxLayout1->addLayout(hboxLayout);


        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, vboxLayout1);


        verticalLayout->addWidget(vncGroupBox);

        sshTunnelLayout = new QHBoxLayout();
        sshTunnelLayout->setSpacing(0);
        sshTunnelLayout->setObjectName("sshTunnelLayout");

        verticalLayout->addLayout(sshTunnelLayout);

        dont_copy_passwords = new QCheckBox(VncPreferences);
        dont_copy_passwords->setObjectName("dont_copy_passwords");

        verticalLayout->addWidget(dont_copy_passwords);

        verticalSpacer = new QSpacerItem(428, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        connectionLabel->setBuddy(kcfg_Quality);
        widthLabel->setBuddy(kcfg_ScalingWidth);
        heightLabel->setBuddy(kcfg_ScalingHeight);
#endif // QT_CONFIG(shortcut)

        retranslateUi(VncPreferences);

        resolutionComboBox->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(VncPreferences);
    } // setupUi

    void retranslateUi(QWidget *VncPreferences)
    {
        vncGroupBox->setTitle(tr2i18n("Connection", nullptr));
        connectionLabel->setText(tr2i18n("Connection &type:", nullptr));
        kcfg_Quality->setItemText(0, tr2i18n("High Quality (LAN, direct connection)", nullptr));
        kcfg_Quality->setItemText(1, tr2i18n("Medium Quality (DSL, Cable, fast Internet)", nullptr));
        kcfg_Quality->setItemText(2, tr2i18n("Low Quality (Modem, ISDN, slow Internet)", nullptr));

#if QT_CONFIG(whatsthis)
        kcfg_Quality->setWhatsThis(tr2i18n("Use this to specify the performance of your connection. Note that you should select the speed of the weakest link - even if you have a high speed connection, it will not help you if the remote computer uses a slow modem. Choosing a level of quality that is too high on a slow link will cause slower response times. Choosing a lower quality will increase latencies in high speed connections and results in lower image quality, especially in 'Low Quality' mode.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_Scaling->setText(tr2i18n("Scale to Size:", nullptr));
        resolutionComboBox->setItemText(0, tr2i18n("Minimal (640x480)", nullptr));
        resolutionComboBox->setItemText(1, tr2i18n("Small (800x600)", nullptr));
        resolutionComboBox->setItemText(2, tr2i18n("Normal (1024x768)", nullptr));
        resolutionComboBox->setItemText(3, tr2i18n("Large (1280x1024)", nullptr));
        resolutionComboBox->setItemText(4, tr2i18n("Very Large (1600x1200)", nullptr));
        resolutionComboBox->setItemText(5, tr2i18n("Current Screen Resolution", nullptr));
        resolutionComboBox->setItemText(6, tr2i18n("Custom Resolution (\342\200\246)", nullptr));

#if QT_CONFIG(whatsthis)
        resolutionComboBox->setWhatsThis(tr2i18n("Here you can specify the resolution of the remote desktop. This resolution determines the size of the desktop that will be presented to you.", nullptr));
#endif // QT_CONFIG(whatsthis)
        widthLabel->setText(tr2i18n("&Width:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_ScalingWidth->setWhatsThis(tr2i18n("This is the width of the remote desktop. You can only change this value manually if you select Custom as desktop resolution above.", nullptr));
#endif // QT_CONFIG(whatsthis)
        heightLabel->setText(tr2i18n("H&eight:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_ScalingHeight->setWhatsThis(tr2i18n("This is the height of the remote desktop. You can only change this value manually if you select Custom as desktop resolution above.", nullptr));
#endif // QT_CONFIG(whatsthis)
        dont_copy_passwords->setText(tr2i18n("Don't copy passwords from supported password managers to remote hosts", nullptr));
#if QT_CONFIG(tooltip)
        dont_copy_passwords->setToolTip(tr2i18n("Supported password managers (like KeePassXC) mark copied passwords with an additional MIME type \"x-kde-passwordManagerHint\" which is used for filtering.", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)VncPreferences;
    } // retranslateUi

};

namespace Ui {
    class VncPreferences: public Ui_VncPreferences {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VNCPREFERENCES_H

