/****************************************************************************
** Meta object code from reading C++ file 'vncclientthread.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../krdc-26.04.3/vnc/vncclientthread.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'vncclientthread.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15VncClientThreadE_t {};
} // unnamed namespace

template <> constexpr inline auto VncClientThread::qt_create_metaobjectdata<qt_meta_tag_ZN15VncClientThreadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "VncClientThread",
        "imageUpdated",
        "",
        "x",
        "y",
        "w",
        "h",
        "gotCut",
        "text",
        "gotCursor",
        "QCursor",
        "cursor",
        "passwordRequest",
        "includingUsername",
        "outputErrorMessage",
        "message",
        "clientStateChanged",
        "RemoteView::RemoteStatus",
        "status",
        "details",
        "mouseEvent",
        "buttonMask",
        "keyEvent",
        "key",
        "pressed",
        "clientCut",
        "checkOutputErrorMessage",
        "ColorDepth",
        "bpp32",
        "bpp16",
        "bpp8"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'imageUpdated'
        QtMocHelpers::SignalData<void(int, int, int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 }, { QMetaType::Int, 5 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'gotCut'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'gotCursor'
        QtMocHelpers::SignalData<void(const QCursor &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'passwordRequest'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'passwordRequest'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'outputErrorMessage'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'clientStateChanged'
        QtMocHelpers::SignalData<void(RemoteView::RemoteStatus, const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'mouseEvent'
        QtMocHelpers::SlotData<void(int, int, int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'keyEvent'
        QtMocHelpers::SlotData<void(int, bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::Bool, 24 },
        }}),
        // Slot 'clientCut'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'checkOutputErrorMessage'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ColorDepth'
        QtMocHelpers::EnumData<enum ColorDepth>(27, 27, QMC::EnumFlags{}).add({
            {   28, ColorDepth::bpp32 },
            {   29, ColorDepth::bpp16 },
            {   30, ColorDepth::bpp8 },
        }),
    };
    return QtMocHelpers::metaObjectData<VncClientThread, qt_meta_tag_ZN15VncClientThreadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject VncClientThread::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15VncClientThreadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15VncClientThreadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15VncClientThreadE_t>.metaTypes,
    nullptr
} };

void VncClientThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VncClientThread *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->imageUpdated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 1: _t->gotCut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->gotCursor((*reinterpret_cast<std::add_pointer_t<QCursor>>(_a[1]))); break;
        case 3: _t->passwordRequest((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->passwordRequest(); break;
        case 5: _t->outputErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->clientStateChanged((*reinterpret_cast<std::add_pointer_t<RemoteView::RemoteStatus>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->mouseEvent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 8: _t->keyEvent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->clientCut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->checkOutputErrorMessage(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VncClientThread::*)(int , int , int , int )>(_a, &VncClientThread::imageUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VncClientThread::*)(const QString & )>(_a, &VncClientThread::gotCut, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (VncClientThread::*)(const QCursor & )>(_a, &VncClientThread::gotCursor, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (VncClientThread::*)(bool )>(_a, &VncClientThread::passwordRequest, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (VncClientThread::*)(const QString & )>(_a, &VncClientThread::outputErrorMessage, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (VncClientThread::*)(RemoteView::RemoteStatus , const QString & )>(_a, &VncClientThread::clientStateChanged, 6))
            return;
    }
}

const QMetaObject *VncClientThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VncClientThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15VncClientThreadE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int VncClientThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void VncClientThread::imageUpdated(int _t1, int _t2, int _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void VncClientThread::gotCut(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void VncClientThread::gotCursor(const QCursor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void VncClientThread::passwordRequest(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 5
void VncClientThread::outputErrorMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void VncClientThread::clientStateChanged(RemoteView::RemoteStatus _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}
QT_WARNING_POP
