// This file is generated by kconfig_compiler_kf6 from krdc.kcfg.
// All changes you do to this file will be lost.
#ifndef SETTINGS_H
#define SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

#include <krdccore_export.h>

class KRDCCORE_EXPORT Settings : public KConfigSkeleton
{
  public:

    static Settings *self();
    ~Settings() override;

    /**
      Set RememberSessions
    */
    static
    void setRememberSessions( bool v )
    {
      if (!self()->isRememberSessionsImmutable())
        self()->mRememberSessions = v;
    }

    /**
      Get RememberSessions
    */
    static
    bool rememberSessions()
    {
      return self()->mRememberSessions;
    }

    /**
      Is RememberSessions Immutable
    */
    static
    bool isRememberSessionsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "RememberSessions" ) );
    }

    /**
      Set RememberHistory
    */
    static
    void setRememberHistory( bool v )
    {
      if (!self()->isRememberHistoryImmutable())
        self()->mRememberHistory = v;
    }

    /**
      Get RememberHistory
    */
    static
    bool rememberHistory()
    {
      return self()->mRememberHistory;
    }

    /**
      Is RememberHistory Immutable
    */
    static
    bool isRememberHistoryImmutable()
    {
      return self()->isImmutable( QStringLiteral( "RememberHistory" ) );
    }

    /**
      Set Sessions
    */
    static
    void setOpenSessions( const QStringList & v )
    {
      if (!self()->isOpenSessionsImmutable())
        self()->mOpenSessions = v;
    }

    /**
      Get Sessions
    */
    static
    QStringList openSessions()
    {
      return self()->mOpenSessions;
    }

    /**
      Is Sessions Immutable
    */
    static
    bool isOpenSessionsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "OpenSessions" ) );
    }

    /**
      Set NormalUrlInputLine
    */
    static
    void setNormalUrlInputLine( bool v )
    {
      if (!self()->isNormalUrlInputLineImmutable())
        self()->mNormalUrlInputLine = v;
    }

    /**
      Get NormalUrlInputLine
    */
    static
    bool normalUrlInputLine()
    {
      return self()->mNormalUrlInputLine;
    }

    /**
      Is NormalUrlInputLine Immutable
    */
    static
    bool isNormalUrlInputLineImmutable()
    {
      return self()->isImmutable( QStringLiteral( "NormalUrlInputLine" ) );
    }

    /**
      Set ShowPreferencesForNewConnections
    */
    static
    void setShowPreferencesForNewConnections( bool v )
    {
      if (!self()->isShowPreferencesForNewConnectionsImmutable())
        self()->mShowPreferencesForNewConnections = v;
    }

    /**
      Get ShowPreferencesForNewConnections
    */
    static
    bool showPreferencesForNewConnections()
    {
      return self()->mShowPreferencesForNewConnections;
    }

    /**
      Is ShowPreferencesForNewConnections Immutable
    */
    static
    bool isShowPreferencesForNewConnectionsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ShowPreferencesForNewConnections" ) );
    }

    /**
      Set ResizeOnConnect
    */
    static
    void setResizeOnConnect( bool v )
    {
      if (!self()->isResizeOnConnectImmutable())
        self()->mResizeOnConnect = v;
    }

    /**
      Get ResizeOnConnect
    */
    static
    bool resizeOnConnect()
    {
      return self()->mResizeOnConnect;
    }

    /**
      Is ResizeOnConnect Immutable
    */
    static
    bool isResizeOnConnectImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ResizeOnConnect" ) );
    }

    /**
      Set FullscreenOnConnect
    */
    static
    void setFullscreenOnConnect( bool v )
    {
      if (!self()->isFullscreenOnConnectImmutable())
        self()->mFullscreenOnConnect = v;
    }

    /**
      Get FullscreenOnConnect
    */
    static
    bool fullscreenOnConnect()
    {
      return self()->mFullscreenOnConnect;
    }

    /**
      Is FullscreenOnConnect Immutable
    */
    static
    bool isFullscreenOnConnectImmutable()
    {
      return self()->isImmutable( QStringLiteral( "FullscreenOnConnect" ) );
    }

    /**
      Set GrabAllKeysOnFullscreen
    */
    static
    void setGrabAllKeysOnFullscreen( bool v )
    {
      if (!self()->isGrabAllKeysOnFullscreenImmutable())
        self()->mGrabAllKeysOnFullscreen = v;
    }

    /**
      Get GrabAllKeysOnFullscreen
    */
    static
    bool grabAllKeysOnFullscreen()
    {
      return self()->mGrabAllKeysOnFullscreen;
    }

    /**
      Is GrabAllKeysOnFullscreen Immutable
    */
    static
    bool isGrabAllKeysOnFullscreenImmutable()
    {
      return self()->isImmutable( QStringLiteral( "GrabAllKeysOnFullscreen" ) );
    }

    /**
      Set BackgroundColor
    */
    static
    void setBackgroundColor( const QColor & v )
    {
      if (!self()->isBackgroundColorImmutable())
        self()->mBackgroundColor = v;
    }

    /**
      Get BackgroundColor
    */
    static
    QColor backgroundColor()
    {
      return self()->mBackgroundColor;
    }

    /**
      Is BackgroundColor Immutable
    */
    static
    bool isBackgroundColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "BackgroundColor" ) );
    }

    /**
      Set WalletSupport
    */
    static
    void setWalletSupport( bool v )
    {
      if (!self()->isWalletSupportImmutable())
        self()->mWalletSupport = v;
    }

    /**
      Get WalletSupport
    */
    static
    bool walletSupport()
    {
      return self()->mWalletSupport;
    }

    /**
      Is WalletSupport Immutable
    */
    static
    bool isWalletSupportImmutable()
    {
      return self()->isImmutable( QStringLiteral( "WalletSupport" ) );
    }

    /**
      Set SystemTrayIcon
    */
    static
    void setSystemTrayIcon( bool v )
    {
      if (!self()->isSystemTrayIconImmutable())
        self()->mSystemTrayIcon = v;
    }

    /**
      Get SystemTrayIcon
    */
    static
    bool systemTrayIcon()
    {
      return self()->mSystemTrayIcon;
    }

    /**
      Is SystemTrayIcon Immutable
    */
    static
    bool isSystemTrayIconImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SystemTrayIcon" ) );
    }

    /**
      Set KeepAspectRatio
    */
    static
    void setKeepAspectRatio( bool v )
    {
      if (!self()->isKeepAspectRatioImmutable())
        self()->mKeepAspectRatio = v;
    }

    /**
      Get KeepAspectRatio
    */
    static
    bool keepAspectRatio()
    {
      return self()->mKeepAspectRatio;
    }

    /**
      Is KeepAspectRatio Immutable
    */
    static
    bool isKeepAspectRatioImmutable()
    {
      return self()->isImmutable( QStringLiteral( "KeepAspectRatio" ) );
    }

    /**
      Set TabCloseButton
    */
    static
    void setTabCloseButton( bool v )
    {
      if (!self()->isTabCloseButtonImmutable())
        self()->mTabCloseButton = v;
    }

    /**
      Get TabCloseButton
    */
    static
    bool tabCloseButton()
    {
      return self()->mTabCloseButton;
    }

    /**
      Is TabCloseButton Immutable
    */
    static
    bool isTabCloseButtonImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TabCloseButton" ) );
    }

    /**
      Set TabMiddleClick
    */
    static
    void setTabMiddleClick( bool v )
    {
      if (!self()->isTabMiddleClickImmutable())
        self()->mTabMiddleClick = v;
    }

    /**
      Get TabMiddleClick
    */
    static
    bool tabMiddleClick()
    {
      return self()->mTabMiddleClick;
    }

    /**
      Is TabMiddleClick Immutable
    */
    static
    bool isTabMiddleClickImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TabMiddleClick" ) );
    }

    /**
      Set TabPosition
    */
    static
    void setTabPosition( int v )
    {
      if (!self()->isTabPositionImmutable())
        self()->mTabPosition = v;
    }

    /**
      Get TabPosition
    */
    static
    int tabPosition()
    {
      return self()->mTabPosition;
    }

    /**
      Is TabPosition Immutable
    */
    static
    bool isTabPositionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TabPosition" ) );
    }

    /**
      Set ShowTabBar
    */
    static
    void setShowTabBar( bool v )
    {
      if (!self()->isShowTabBarImmutable())
        self()->mShowTabBar = v;
    }

    /**
      Get ShowTabBar
    */
    static
    bool showTabBar()
    {
      return self()->mShowTabBar;
    }

    /**
      Is ShowTabBar Immutable
    */
    static
    bool isShowTabBarImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ShowTabBar" ) );
    }

    /**
      Set ShowStatusBar
    */
    static
    void setShowStatusBar( bool v )
    {
      if (!self()->isShowStatusBarImmutable())
        self()->mShowStatusBar = v;
    }

    /**
      Get ShowStatusBar
    */
    static
    bool showStatusBar()
    {
      return self()->mShowStatusBar;
    }

    /**
      Is ShowStatusBar Immutable
    */
    static
    bool isShowStatusBarImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ShowStatusBar" ) );
    }

    /**
      Set ConnectionListSortColumn
    */
    static
    void setConnectionListSortColumn( int v )
    {
      if (!self()->isConnectionListSortColumnImmutable())
        self()->mConnectionListSortColumn = v;
    }

    /**
      Get ConnectionListSortColumn
    */
    static
    int connectionListSortColumn()
    {
      return self()->mConnectionListSortColumn;
    }

    /**
      Is ConnectionListSortColumn Immutable
    */
    static
    bool isConnectionListSortColumnImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ConnectionListSortColumn" ) );
    }

    /**
      Set ConnectionListSortOrder
    */
    static
    void setConnectionListSortOrder( int v )
    {
      if (!self()->isConnectionListSortOrderImmutable())
        self()->mConnectionListSortOrder = v;
    }

    /**
      Get ConnectionListSortOrder
    */
    static
    int connectionListSortOrder()
    {
      return self()->mConnectionListSortOrder;
    }

    /**
      Is ConnectionListSortOrder Immutable
    */
    static
    bool isConnectionListSortOrderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ConnectionListSortOrder" ) );
    }

    /**
      Set DefaultProtocol
    */
    static
    void setDefaultProtocol( const QString & v )
    {
      if (!self()->isDefaultProtocolImmutable())
        self()->mDefaultProtocol = v;
    }

    /**
      Get DefaultProtocol
    */
    static
    QString defaultProtocol()
    {
      return self()->mDefaultProtocol;
    }

    /**
      Is DefaultProtocol Immutable
    */
    static
    bool isDefaultProtocolImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DefaultProtocol" ) );
    }

    /**
      Set Quality
    */
    static
    void setQuality( int v )
    {
      if (!self()->isQualityImmutable())
        self()->mQuality = v;
    }

    /**
      Get Quality
    */
    static
    int quality()
    {
      return self()->mQuality;
    }

    /**
      Is Quality Immutable
    */
    static
    bool isQualityImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Quality" ) );
    }

    /**
      Set Scaling
    */
    static
    void setScaling( bool v )
    {
      if (!self()->isScalingImmutable())
        self()->mScaling = v;
    }

    /**
      Get Scaling
    */
    static
    bool scaling()
    {
      return self()->mScaling;
    }

    /**
      Is Scaling Immutable
    */
    static
    bool isScalingImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Scaling" ) );
    }

    /**
      Set ScalingWidth
    */
    static
    void setScalingWidth( int v )
    {
      if (!self()->isScalingWidthImmutable())
        self()->mScalingWidth = v;
    }

    /**
      Get ScalingWidth
    */
    static
    int scalingWidth()
    {
      return self()->mScalingWidth;
    }

    /**
      Is ScalingWidth Immutable
    */
    static
    bool isScalingWidthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ScalingWidth" ) );
    }

    /**
      Set ScalingHeight
    */
    static
    void setScalingHeight( int v )
    {
      if (!self()->isScalingHeightImmutable())
        self()->mScalingHeight = v;
    }

    /**
      Get ScalingHeight
    */
    static
    int scalingHeight()
    {
      return self()->mScalingHeight;
    }

    /**
      Is ScalingHeight Immutable
    */
    static
    bool isScalingHeightImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ScalingHeight" ) );
    }

    /**
      Set Width
    */
    static
    void setWidth( int v )
    {
      if (!self()->isWidthImmutable())
        self()->mWidth = v;
    }

    /**
      Get Width
    */
    static
    int width()
    {
      return self()->mWidth;
    }

    /**
      Is Width Immutable
    */
    static
    bool isWidthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Width" ) );
    }

    /**
      Set Height
    */
    static
    void setHeight( int v )
    {
      if (!self()->isHeightImmutable())
        self()->mHeight = v;
    }

    /**
      Get Height
    */
    static
    int height()
    {
      return self()->mHeight;
    }

    /**
      Is Height Immutable
    */
    static
    bool isHeightImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Height" ) );
    }

    /**
      Set KeyboardLayout
    */
    static
    void setKeyboardLayout( int v )
    {
      if (!self()->isKeyboardLayoutImmutable())
        self()->mKeyboardLayout = v;
    }

    /**
      Get KeyboardLayout
    */
    static
    int keyboardLayout()
    {
      return self()->mKeyboardLayout;
    }

    /**
      Is KeyboardLayout Immutable
    */
    static
    bool isKeyboardLayoutImmutable()
    {
      return self()->isImmutable( QStringLiteral( "KeyboardLayout" ) );
    }

    /**
      Set Resolution
    */
    static
    void setResolution( int v )
    {
      if (!self()->isResolutionImmutable())
        self()->mResolution = v;
    }

    /**
      Get Resolution
    */
    static
    int resolution()
    {
      return self()->mResolution;
    }

    /**
      Is Resolution Immutable
    */
    static
    bool isResolutionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Resolution" ) );
    }

    /**
      Set Acceleration
    */
    static
    void setAcceleration( int v )
    {
      if (!self()->isAccelerationImmutable())
        self()->mAcceleration = v;
    }

    /**
      Get Acceleration
    */
    static
    int acceleration()
    {
      return self()->mAcceleration;
    }

    /**
      Is Acceleration Immutable
    */
    static
    bool isAccelerationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Acceleration" ) );
    }

    /**
      Set ColorDepth
    */
    static
    void setColorDepth( int v )
    {
      if (!self()->isColorDepthImmutable())
        self()->mColorDepth = v;
    }

    /**
      Get ColorDepth
    */
    static
    int colorDepth()
    {
      return self()->mColorDepth;
    }

    /**
      Is ColorDepth Immutable
    */
    static
    bool isColorDepthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ColorDepth" ) );
    }

    /**
      Set DesktopScaleFactor
    */
    static
    void setDesktopScaleFactor( int v )
    {
      if (!self()->isDesktopScaleFactorImmutable())
        self()->mDesktopScaleFactor = v;
    }

    /**
      Get DesktopScaleFactor
    */
    static
    int desktopScaleFactor()
    {
      return self()->mDesktopScaleFactor;
    }

    /**
      Is DesktopScaleFactor Immutable
    */
    static
    bool isDesktopScaleFactorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DesktopScaleFactor" ) );
    }

    /**
      Set DesktopScaleFactorCustom
    */
    static
    void setDesktopScaleFactorCustom( int v )
    {
      if (!self()->isDesktopScaleFactorCustomImmutable())
        self()->mDesktopScaleFactorCustom = v;
    }

    /**
      Get DesktopScaleFactorCustom
    */
    static
    int desktopScaleFactorCustom()
    {
      return self()->mDesktopScaleFactorCustom;
    }

    /**
      Is DesktopScaleFactorCustom Immutable
    */
    static
    bool isDesktopScaleFactorCustomImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DesktopScaleFactorCustom" ) );
    }

    /**
      Set DeviceScaleFactor
    */
    static
    void setDeviceScaleFactor( int v )
    {
      if (!self()->isDeviceScaleFactorImmutable())
        self()->mDeviceScaleFactor = v;
    }

    /**
      Get DeviceScaleFactor
    */
    static
    int deviceScaleFactor()
    {
      return self()->mDeviceScaleFactor;
    }

    /**
      Is DeviceScaleFactor Immutable
    */
    static
    bool isDeviceScaleFactorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DeviceScaleFactor" ) );
    }

    /**
      Set Sound
    */
    static
    void setSound( int v )
    {
      if (!self()->isSoundImmutable())
        self()->mSound = v;
    }

    /**
      Get Sound
    */
    static
    int sound()
    {
      return self()->mSound;
    }

    /**
      Is Sound Immutable
    */
    static
    bool isSoundImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Sound" ) );
    }

    /**
      Set DefaultRdpUserName
    */
    static
    void setDefaultRdpUserName( const QString & v )
    {
      if (!self()->isDefaultRdpUserNameImmutable())
        self()->mDefaultRdpUserName = v;
    }

    /**
      Get DefaultRdpUserName
    */
    static
    QString defaultRdpUserName()
    {
      return self()->mDefaultRdpUserName;
    }

    /**
      Is DefaultRdpUserName Immutable
    */
    static
    bool isDefaultRdpUserNameImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DefaultRdpUserName" ) );
    }

    /**
      Set RecognizeLdapLogins
    */
    static
    void setRecognizeLdapLogins( bool v )
    {
      if (!self()->isRecognizeLdapLoginsImmutable())
        self()->mRecognizeLdapLogins = v;
    }

    /**
      Get RecognizeLdapLogins
    */
    static
    bool recognizeLdapLogins()
    {
      return self()->mRecognizeLdapLogins;
    }

    /**
      Is RecognizeLdapLogins Immutable
    */
    static
    bool isRecognizeLdapLoginsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "RecognizeLdapLogins" ) );
    }

    /**
      Set ShareMedia
    */
    static
    void setShareMedia( const QString & v )
    {
      if (!self()->isShareMediaImmutable())
        self()->mShareMedia = v;
    }

    /**
      Get ShareMedia
    */
    static
    QString shareMedia()
    {
      return self()->mShareMedia;
    }

    /**
      Is ShareMedia Immutable
    */
    static
    bool isShareMediaImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ShareMedia" ) );
    }

    /**
      Set ScaleToSize
    */
    static
    void setScaleToSize( bool v )
    {
      if (!self()->isScaleToSizeImmutable())
        self()->mScaleToSize = v;
    }

    /**
      Get ScaleToSize
    */
    static
    bool scaleToSize()
    {
      return self()->mScaleToSize;
    }

    /**
      Is ScaleToSize Immutable
    */
    static
    bool isScaleToSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ScaleToSize" ) );
    }

    /**
      Set ConsoleMode
    */
    static
    void setConsoleMode( bool v )
    {
      if (!self()->isConsoleModeImmutable())
        self()->mConsoleMode = v;
    }

    /**
      Get ConsoleMode
    */
    static
    bool consoleMode()
    {
      return self()->mConsoleMode;
    }

    /**
      Is ConsoleMode Immutable
    */
    static
    bool isConsoleModeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ConsoleMode" ) );
    }

    /**
      Set PreventSessionLock
    */
    static
    void setPreventSessionLock( bool v )
    {
      if (!self()->isPreventSessionLockImmutable())
        self()->mPreventSessionLock = v;
    }

    /**
      Get PreventSessionLock
    */
    static
    bool preventSessionLock()
    {
      return self()->mPreventSessionLock;
    }

    /**
      Is PreventSessionLock Immutable
    */
    static
    bool isPreventSessionLockImmutable()
    {
      return self()->isImmutable( QStringLiteral( "PreventSessionLock" ) );
    }

    /**
      Set TlsSecLevel
    */
    static
    void setTlsSecLevel( int v )
    {
      if (!self()->isTlsSecLevelImmutable())
        self()->mTlsSecLevel = v;
    }

    /**
      Get TlsSecLevel
    */
    static
    int tlsSecLevel()
    {
      return self()->mTlsSecLevel;
    }

    /**
      Is TlsSecLevel Immutable
    */
    static
    bool isTlsSecLevelImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TlsSecLevel" ) );
    }

    /**
      Set ProxyProtocol
    */
    static
    void setProxyProtocol( int v )
    {
      if (!self()->isProxyProtocolImmutable())
        self()->mProxyProtocol = v;
    }

    /**
      Get ProxyProtocol
    */
    static
    int proxyProtocol()
    {
      return self()->mProxyProtocol;
    }

    /**
      Is ProxyProtocol Immutable
    */
    static
    bool isProxyProtocolImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ProxyProtocol" ) );
    }

    /**
      Set ProxyUsername
    */
    static
    void setProxyUsername( const QString & v )
    {
      if (!self()->isProxyUsernameImmutable())
        self()->mProxyUsername = v;
    }

    /**
      Get ProxyUsername
    */
    static
    QString proxyUsername()
    {
      return self()->mProxyUsername;
    }

    /**
      Is ProxyUsername Immutable
    */
    static
    bool isProxyUsernameImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ProxyUsername" ) );
    }

    /**
      Set ProxyPassword
    */
    static
    void setProxyPassword( const QString & v )
    {
      if (!self()->isProxyPasswordImmutable())
        self()->mProxyPassword = v;
    }

    /**
      Get ProxyPassword
    */
    static
    QString proxyPassword()
    {
      return self()->mProxyPassword;
    }

    /**
      Is ProxyPassword Immutable
    */
    static
    bool isProxyPasswordImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ProxyPassword" ) );
    }

    /**
      Set ProxyHost
    */
    static
    void setProxyHost( const QString & v )
    {
      if (!self()->isProxyHostImmutable())
        self()->mProxyHost = v;
    }

    /**
      Get ProxyHost
    */
    static
    QString proxyHost()
    {
      return self()->mProxyHost;
    }

    /**
      Is ProxyHost Immutable
    */
    static
    bool isProxyHostImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ProxyHost" ) );
    }

    /**
      Set GatewayTransportType
    */
    static
    void setGatewayTransportType( int v )
    {
      if (!self()->isGatewayTransportTypeImmutable())
        self()->mGatewayTransportType = v;
    }

    /**
      Get GatewayTransportType
    */
    static
    int gatewayTransportType()
    {
      return self()->mGatewayTransportType;
    }

    /**
      Is GatewayTransportType Immutable
    */
    static
    bool isGatewayTransportTypeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "GatewayTransportType" ) );
    }

    /**
      Set GatewayUsername
    */
    static
    void setGatewayUsername( const QString & v )
    {
      if (!self()->isGatewayUsernameImmutable())
        self()->mGatewayUsername = v;
    }

    /**
      Get GatewayUsername
    */
    static
    QString gatewayUsername()
    {
      return self()->mGatewayUsername;
    }

    /**
      Is GatewayUsername Immutable
    */
    static
    bool isGatewayUsernameImmutable()
    {
      return self()->isImmutable( QStringLiteral( "GatewayUsername" ) );
    }

    /**
      Set GatewayPassword
    */
    static
    void setGatewayPassword( const QString & v )
    {
      if (!self()->isGatewayPasswordImmutable())
        self()->mGatewayPassword = v;
    }

    /**
      Get GatewayPassword
    */
    static
    QString gatewayPassword()
    {
      return self()->mGatewayPassword;
    }

    /**
      Is GatewayPassword Immutable
    */
    static
    bool isGatewayPasswordImmutable()
    {
      return self()->isImmutable( QStringLiteral( "GatewayPassword" ) );
    }

    /**
      Set GatewayServer
    */
    static
    void setGatewayServer( const QString & v )
    {
      if (!self()->isGatewayServerImmutable())
        self()->mGatewayServer = v;
    }

    /**
      Get GatewayServer
    */
    static
    QString gatewayServer()
    {
      return self()->mGatewayServer;
    }

    /**
      Is GatewayServer Immutable
    */
    static
    bool isGatewayServerImmutable()
    {
      return self()->isImmutable( QStringLiteral( "GatewayServer" ) );
    }

    /**
      Set GatewayDomain
    */
    static
    void setGatewayDomain( const QString & v )
    {
      if (!self()->isGatewayDomainImmutable())
        self()->mGatewayDomain = v;
    }

    /**
      Get GatewayDomain
    */
    static
    QString gatewayDomain()
    {
      return self()->mGatewayDomain;
    }

    /**
      Is GatewayDomain Immutable
    */
    static
    bool isGatewayDomainImmutable()
    {
      return self()->isImmutable( QStringLiteral( "GatewayDomain" ) );
    }

    /**
      Set SmartcardName
    */
    static
    void setSmartcardName( const QString & v )
    {
      if (!self()->isSmartcardNameImmutable())
        self()->mSmartcardName = v;
    }

    /**
      Get SmartcardName
    */
    static
    QString smartcardName()
    {
      return self()->mSmartcardName;
    }

    /**
      Is SmartcardName Immutable
    */
    static
    bool isSmartcardNameImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SmartcardName" ) );
    }

    /**
      Set SecurityNLA
    */
    static
    void setSecurityNLA( bool v )
    {
      if (!self()->isSecurityNLAImmutable())
        self()->mSecurityNLA = v;
    }

    /**
      Get SecurityNLA
    */
    static
    bool securityNLA()
    {
      return self()->mSecurityNLA;
    }

    /**
      Is SecurityNLA Immutable
    */
    static
    bool isSecurityNLAImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SecurityNLA" ) );
    }

    /**
      Set SecurityTLS
    */
    static
    void setSecurityTLS( bool v )
    {
      if (!self()->isSecurityTLSImmutable())
        self()->mSecurityTLS = v;
    }

    /**
      Get SecurityTLS
    */
    static
    bool securityTLS()
    {
      return self()->mSecurityTLS;
    }

    /**
      Is SecurityTLS Immutable
    */
    static
    bool isSecurityTLSImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SecurityTLS" ) );
    }

    /**
      Set SecurityRDP
    */
    static
    void setSecurityRDP( bool v )
    {
      if (!self()->isSecurityRDPImmutable())
        self()->mSecurityRDP = v;
    }

    /**
      Get SecurityRDP
    */
    static
    bool securityRDP()
    {
      return self()->mSecurityRDP;
    }

    /**
      Is SecurityRDP Immutable
    */
    static
    bool isSecurityRDPImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SecurityRDP" ) );
    }

    /**
      Set SecurityEXT
    */
    static
    void setSecurityEXT( bool v )
    {
      if (!self()->isSecurityEXTImmutable())
        self()->mSecurityEXT = v;
    }

    /**
      Get SecurityEXT
    */
    static
    bool securityEXT()
    {
      return self()->mSecurityEXT;
    }

    /**
      Is SecurityEXT Immutable
    */
    static
    bool isSecurityEXTImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SecurityEXT" ) );
    }

    /**
      Set AuthPkgList
    */
    static
    void setAuthPkgList( const QString & v )
    {
      if (!self()->isAuthPkgListImmutable())
        self()->mAuthPkgList = v;
    }

    /**
      Get AuthPkgList
    */
    static
    QString authPkgList()
    {
      return self()->mAuthPkgList;
    }

    /**
      Is AuthPkgList Immutable
    */
    static
    bool isAuthPkgListImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AuthPkgList" ) );
    }

    /**
      Set NxWidth
    */
    static
    void setNxWidth( int v )
    {
      if (!self()->isNxWidthImmutable())
        self()->mNxWidth = v;
    }

    /**
      Get NxWidth
    */
    static
    int nxWidth()
    {
      return self()->mNxWidth;
    }

    /**
      Is NxWidth Immutable
    */
    static
    bool isNxWidthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "NxWidth" ) );
    }

    /**
      Set NxHeight
    */
    static
    void setNxHeight( int v )
    {
      if (!self()->isNxHeightImmutable())
        self()->mNxHeight = v;
    }

    /**
      Get NxHeight
    */
    static
    int nxHeight()
    {
      return self()->mNxHeight;
    }

    /**
      Is NxHeight Immutable
    */
    static
    bool isNxHeightImmutable()
    {
      return self()->isImmutable( QStringLiteral( "NxHeight" ) );
    }

    /**
      Set NxDesktopType
    */
    static
    void setNxDesktopType( int v )
    {
      if (!self()->isNxDesktopTypeImmutable())
        self()->mNxDesktopType = v;
    }

    /**
      Get NxDesktopType
    */
    static
    int nxDesktopType()
    {
      return self()->mNxDesktopType;
    }

    /**
      Is NxDesktopType Immutable
    */
    static
    bool isNxDesktopTypeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "NxDesktopType" ) );
    }

    /**
      Set NxKeyboardLayout
    */
    static
    void setNxKeyboardLayout( int v )
    {
      if (!self()->isNxKeyboardLayoutImmutable())
        self()->mNxKeyboardLayout = v;
    }

    /**
      Get NxKeyboardLayout
    */
    static
    int nxKeyboardLayout()
    {
      return self()->mNxKeyboardLayout;
    }

    /**
      Is NxKeyboardLayout Immutable
    */
    static
    bool isNxKeyboardLayoutImmutable()
    {
      return self()->isImmutable( QStringLiteral( "NxKeyboardLayout" ) );
    }

    /**
      Set NxPrivateKey
    */
    static
    void setNxPrivateKey( const QString & v )
    {
      if (!self()->isNxPrivateKeyImmutable())
        self()->mNxPrivateKey = v;
    }

    /**
      Get NxPrivateKey
    */
    static
    QString nxPrivateKey()
    {
      return self()->mNxPrivateKey;
    }

    /**
      Is NxPrivateKey Immutable
    */
    static
    bool isNxPrivateKeyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "NxPrivateKey" ) );
    }

  protected:
    Settings();
    friend class SettingsHelper;


    // General
    bool mRememberSessions;
    bool mRememberHistory;
    QStringList mOpenSessions;
    bool mNormalUrlInputLine;
    bool mShowPreferencesForNewConnections;
    bool mResizeOnConnect;
    bool mFullscreenOnConnect;
    bool mGrabAllKeysOnFullscreen;
    QColor mBackgroundColor;
    bool mWalletSupport;
    bool mSystemTrayIcon;
    bool mKeepAspectRatio;
    bool mTabCloseButton;
    bool mTabMiddleClick;
    int mTabPosition;
    bool mShowTabBar;
    bool mShowStatusBar;
    int mConnectionListSortColumn;
    int mConnectionListSortOrder;
    QString mDefaultProtocol;

    // VNC
    int mQuality;
    bool mScaling;
    int mScalingWidth;
    int mScalingHeight;

    // RDP
    int mWidth;
    int mHeight;
    int mKeyboardLayout;
    int mResolution;
    int mAcceleration;
    int mColorDepth;
    int mDesktopScaleFactor;
    int mDesktopScaleFactorCustom;
    int mDeviceScaleFactor;
    int mSound;
    QString mDefaultRdpUserName;
    bool mRecognizeLdapLogins;
    QString mShareMedia;
    bool mScaleToSize;
    bool mConsoleMode;
    bool mPreventSessionLock;
    int mTlsSecLevel;
    int mProxyProtocol;
    QString mProxyUsername;
    QString mProxyPassword;
    QString mProxyHost;
    int mGatewayTransportType;
    QString mGatewayUsername;
    QString mGatewayPassword;
    QString mGatewayServer;
    QString mGatewayDomain;
    QString mSmartcardName;
    bool mSecurityNLA;
    bool mSecurityTLS;
    bool mSecurityRDP;
    bool mSecurityEXT;
    QString mAuthPkgList;

    // NX
    int mNxWidth;
    int mNxHeight;
    int mNxDesktopType;
    int mNxKeyboardLayout;
    QString mNxPrivateKey;
};

#endif

