/********************************************************************************
** Form generated from reading UI file 'general.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERAL_H
#define UI_GENERAL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_General
{
public:
    QVBoxLayout *verticalLayout_2;
    QCheckBox *kcfg_RememberSessions;
    QCheckBox *kcfg_RememberHistory;
    QCheckBox *kcfg_WalletSupport;
    QCheckBox *kcfg_SystemTrayIcon;
    QCheckBox *kcfg_ShowStatusBar;
    QCheckBox *kcfg_KeepAspectRatio;
    QHBoxLayout *hboxLayout;
    QLabel *backgroundLabel;
    QSpacerItem *spacerItem;
    KColorButton *kcfg_BackgroundColor;
    QGroupBox *connectionGroupBox;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *kcfg_ShowPreferencesForNewConnections;
    QCheckBox *kcfg_ResizeOnConnect;
    QCheckBox *kcfg_FullscreenOnConnect;
    QCheckBox *kcfg_GrabAllKeysOnFullscreen;
    QHBoxLayout *horizontalLayoutP;
    QLabel *defaultProtocolLabel;
    QLineEdit *kcfg_DefaultProtocol;
    QGroupBox *tabGroupBox;
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_ShowTabBar;
    QCheckBox *kcfg_TabCloseButton;
    QCheckBox *kcfg_TabMiddleClick;
    QHBoxLayout *horizontalLayout;
    QLabel *tabOrientationLabel;
    KComboBox *kcfg_TabPosition;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *General)
    {
        if (General->objectName().isEmpty())
            General->setObjectName("General");
        General->resize(363, 464);
        verticalLayout_2 = new QVBoxLayout(General);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_RememberSessions = new QCheckBox(General);
        kcfg_RememberSessions->setObjectName("kcfg_RememberSessions");

        verticalLayout_2->addWidget(kcfg_RememberSessions);

        kcfg_RememberHistory = new QCheckBox(General);
        kcfg_RememberHistory->setObjectName("kcfg_RememberHistory");

        verticalLayout_2->addWidget(kcfg_RememberHistory);

        kcfg_WalletSupport = new QCheckBox(General);
        kcfg_WalletSupport->setObjectName("kcfg_WalletSupport");

        verticalLayout_2->addWidget(kcfg_WalletSupport);

        kcfg_SystemTrayIcon = new QCheckBox(General);
        kcfg_SystemTrayIcon->setObjectName("kcfg_SystemTrayIcon");

        verticalLayout_2->addWidget(kcfg_SystemTrayIcon);

        kcfg_ShowStatusBar = new QCheckBox(General);
        kcfg_ShowStatusBar->setObjectName("kcfg_ShowStatusBar");

        verticalLayout_2->addWidget(kcfg_ShowStatusBar);

        kcfg_KeepAspectRatio = new QCheckBox(General);
        kcfg_KeepAspectRatio->setObjectName("kcfg_KeepAspectRatio");

        verticalLayout_2->addWidget(kcfg_KeepAspectRatio);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        backgroundLabel = new QLabel(General);
        backgroundLabel->setObjectName("backgroundLabel");

        hboxLayout->addWidget(backgroundLabel);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        kcfg_BackgroundColor = new KColorButton(General);
        kcfg_BackgroundColor->setObjectName("kcfg_BackgroundColor");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_BackgroundColor->sizePolicy().hasHeightForWidth());
        kcfg_BackgroundColor->setSizePolicy(sizePolicy);

        hboxLayout->addWidget(kcfg_BackgroundColor);


        verticalLayout_2->addLayout(hboxLayout);

        connectionGroupBox = new QGroupBox(General);
        connectionGroupBox->setObjectName("connectionGroupBox");
        verticalLayout_3 = new QVBoxLayout(connectionGroupBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        kcfg_ShowPreferencesForNewConnections = new QCheckBox(connectionGroupBox);
        kcfg_ShowPreferencesForNewConnections->setObjectName("kcfg_ShowPreferencesForNewConnections");

        verticalLayout_3->addWidget(kcfg_ShowPreferencesForNewConnections);

        kcfg_ResizeOnConnect = new QCheckBox(connectionGroupBox);
        kcfg_ResizeOnConnect->setObjectName("kcfg_ResizeOnConnect");

        verticalLayout_3->addWidget(kcfg_ResizeOnConnect);

        kcfg_FullscreenOnConnect = new QCheckBox(connectionGroupBox);
        kcfg_FullscreenOnConnect->setObjectName("kcfg_FullscreenOnConnect");

        verticalLayout_3->addWidget(kcfg_FullscreenOnConnect);

        kcfg_GrabAllKeysOnFullscreen = new QCheckBox(connectionGroupBox);
        kcfg_GrabAllKeysOnFullscreen->setObjectName("kcfg_GrabAllKeysOnFullscreen");

        verticalLayout_3->addWidget(kcfg_GrabAllKeysOnFullscreen);

        horizontalLayoutP = new QHBoxLayout();
        horizontalLayoutP->setObjectName("horizontalLayoutP");
        defaultProtocolLabel = new QLabel(connectionGroupBox);
        defaultProtocolLabel->setObjectName("defaultProtocolLabel");

        horizontalLayoutP->addWidget(defaultProtocolLabel);

        kcfg_DefaultProtocol = new QLineEdit(connectionGroupBox);
        kcfg_DefaultProtocol->setObjectName("kcfg_DefaultProtocol");

        horizontalLayoutP->addWidget(kcfg_DefaultProtocol);


        verticalLayout_3->addLayout(horizontalLayoutP);


        verticalLayout_2->addWidget(connectionGroupBox);

        tabGroupBox = new QGroupBox(General);
        tabGroupBox->setObjectName("tabGroupBox");
        verticalLayout = new QVBoxLayout(tabGroupBox);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_ShowTabBar = new QCheckBox(tabGroupBox);
        kcfg_ShowTabBar->setObjectName("kcfg_ShowTabBar");

        verticalLayout->addWidget(kcfg_ShowTabBar);

        kcfg_TabCloseButton = new QCheckBox(tabGroupBox);
        kcfg_TabCloseButton->setObjectName("kcfg_TabCloseButton");

        verticalLayout->addWidget(kcfg_TabCloseButton);

        kcfg_TabMiddleClick = new QCheckBox(tabGroupBox);
        kcfg_TabMiddleClick->setObjectName("kcfg_TabMiddleClick");

        verticalLayout->addWidget(kcfg_TabMiddleClick);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        tabOrientationLabel = new QLabel(tabGroupBox);
        tabOrientationLabel->setObjectName("tabOrientationLabel");

        horizontalLayout->addWidget(tabOrientationLabel);

        kcfg_TabPosition = new KComboBox(tabGroupBox);
        kcfg_TabPosition->addItem(QString());
        kcfg_TabPosition->addItem(QString());
        kcfg_TabPosition->addItem(QString());
        kcfg_TabPosition->addItem(QString());
        kcfg_TabPosition->setObjectName("kcfg_TabPosition");

        horizontalLayout->addWidget(kcfg_TabPosition);


        verticalLayout->addLayout(horizontalLayout);


        verticalLayout_2->addWidget(tabGroupBox);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacerItem1);


        retranslateUi(General);

        QMetaObject::connectSlotsByName(General);
    } // setupUi

    void retranslateUi(QWidget *General)
    {
        kcfg_RememberSessions->setText(tr2i18n("Remember open sessions for next startup", nullptr));
        kcfg_RememberHistory->setText(tr2i18n("Remember connection history", nullptr));
        kcfg_WalletSupport->setText(tr2i18n("Remember passwords", nullptr));
        kcfg_SystemTrayIcon->setText(tr2i18n("Enable system tray icon", nullptr));
        kcfg_ShowStatusBar->setText(tr2i18n("Show status bar", nullptr));
        kcfg_KeepAspectRatio->setText(tr2i18n("Keep aspect ratio when scaling", nullptr));
        backgroundLabel->setText(tr2i18n("Background color of empty place:", nullptr));
        connectionGroupBox->setTitle(tr2i18n("When Connecting", nullptr));
        kcfg_ShowPreferencesForNewConnections->setText(tr2i18n("Show the preferences dialog for new connections", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ResizeOnConnect->setToolTip(tr2i18n("This option will resize the window to fit the connection size.  If it is too big, it will maximize the window.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_ResizeOnConnect->setText(tr2i18n("Resize to fit", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_FullscreenOnConnect->setToolTip(tr2i18n("This option switches to fullscreen only if the connection resolution is the same as the current screen resolution", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_FullscreenOnConnect->setText(tr2i18n("Switch to Fullscreen if appropriate", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GrabAllKeysOnFullscreen->setToolTip(tr2i18n("Automatically grab all keys when entering fullscreen mode and release them when leaving fullscreen", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_GrabAllKeysOnFullscreen->setText(tr2i18n("Grab all keys when entering fullscreen", nullptr));
        defaultProtocolLabel->setText(tr2i18n("Default protocol:", nullptr));
        kcfg_DefaultProtocol->setText(tr2i18n("vnc", nullptr));
        tabGroupBox->setTitle(tr2i18n("Tab Settings", nullptr));
        kcfg_ShowTabBar->setText(tr2i18n("Always show tab bar", nullptr));
        kcfg_TabCloseButton->setText(tr2i18n("Show close button on tabs", nullptr));
        kcfg_TabMiddleClick->setText(tr2i18n("Middle-click on a tab closes it", nullptr));
        tabOrientationLabel->setText(tr2i18n("Tab position:", nullptr));
        kcfg_TabPosition->setItemText(0, tr2i18n("Top", nullptr));
        kcfg_TabPosition->setItemText(1, tr2i18n("Bottom", nullptr));
        kcfg_TabPosition->setItemText(2, tr2i18n("Left", nullptr));
        kcfg_TabPosition->setItemText(3, tr2i18n("Right", nullptr));

        (void)General;
    } // retranslateUi

};

namespace Ui {
    class General: public Ui_General {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERAL_H

