/****************************************************************************
** Meta object code from reading C++ file 'rdpsession.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../krdc-26.04.3/rdp/rdpsession.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'rdpsession.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10RdpSessionE_t {};
} // unnamed namespace

template <> constexpr inline auto RdpSession::qt_create_metaobjectdata<qt_meta_tag_ZN10RdpSessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RdpSession",
        "stateChanged",
        "",
        "sizeChanged",
        "rectangleUpdated",
        "QRect",
        "rectangle",
        "QSize",
        "size",
        "errorMessage",
        "error",
        "onAuthRequested",
        "onVerifyCertificate",
        "RdpSession::CertificateResult*",
        "ret",
        "certificate",
        "onVerifyChangedCertificate",
        "oldCertificate",
        "newCertificate",
        "onLogonError",
        "cursorChanged",
        "QCursor",
        "cursor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rectangleUpdated'
        QtMocHelpers::SignalData<void(const QRect &, const QSize &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'errorMessage'
        QtMocHelpers::SignalData<void(unsigned int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 10 },
        }}),
        // Signal 'onAuthRequested'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onVerifyCertificate'
        QtMocHelpers::SignalData<void(RdpSession::CertificateResult *, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { QMetaType::QString, 15 },
        }}),
        // Signal 'onVerifyChangedCertificate'
        QtMocHelpers::SignalData<void(RdpSession::CertificateResult *, const QString &, const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'onLogonError'
        QtMocHelpers::SignalData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'cursorChanged'
        QtMocHelpers::SignalData<void(const QCursor)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RdpSession, qt_meta_tag_ZN10RdpSessionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RdpSession::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10RdpSessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10RdpSessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10RdpSessionE_t>.metaTypes,
    nullptr
} };

void RdpSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RdpSession *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged(); break;
        case 1: _t->sizeChanged(); break;
        case 2: _t->rectangleUpdated((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[2]))); break;
        case 3: _t->errorMessage((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 4: _t->onAuthRequested(); break;
        case 5: _t->onVerifyCertificate((*reinterpret_cast<std::add_pointer_t<RdpSession::CertificateResult*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->onVerifyChangedCertificate((*reinterpret_cast<std::add_pointer_t<RdpSession::CertificateResult*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->onLogonError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->cursorChanged((*reinterpret_cast<std::add_pointer_t<QCursor>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RdpSession::*)()>(_a, &RdpSession::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RdpSession::*)()>(_a, &RdpSession::sizeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RdpSession::*)(const QRect & , const QSize & )>(_a, &RdpSession::rectangleUpdated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RdpSession::*)(unsigned int )>(_a, &RdpSession::errorMessage, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (RdpSession::*)()>(_a, &RdpSession::onAuthRequested, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (RdpSession::*)(RdpSession::CertificateResult * , const QString & )>(_a, &RdpSession::onVerifyCertificate, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (RdpSession::*)(RdpSession::CertificateResult * , const QString & , const QString & )>(_a, &RdpSession::onVerifyChangedCertificate, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (RdpSession::*)(const QString & )>(_a, &RdpSession::onLogonError, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (RdpSession::*)(const QCursor )>(_a, &RdpSession::cursorChanged, 8))
            return;
    }
}

const QMetaObject *RdpSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RdpSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10RdpSessionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int RdpSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void RdpSession::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void RdpSession::sizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void RdpSession::rectangleUpdated(const QRect & _t1, const QSize & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void RdpSession::errorMessage(unsigned int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void RdpSession::onAuthRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void RdpSession::onVerifyCertificate(RdpSession::CertificateResult * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void RdpSession::onVerifyChangedCertificate(RdpSession::CertificateResult * _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void RdpSession::onLogonError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void RdpSession::cursorChanged(const QCursor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
